@@ -86,7 +86,7 @@
   (:node-var node)
   (:note "SSE to pointer coercion")
   (:generator 13
-     (fixed-alloc y simd-pack-widetag simd-pack-size node)
+     (alloc-other y simd-pack-widetag simd-pack-size node)
        ;; see *simd-pack-element-types*
      (storew (fixnumize
               (sc-case x
@@ -189,7 +189,7 @@
   (:result-types t)
   (:node-var node)
   (:generator 13
-    (fixed-alloc dst simd-pack-widetag simd-pack-size node)
+    (alloc-other dst simd-pack-widetag simd-pack-size node)
       ;; see *simd-pack-element-types*
     (storew tag dst simd-pack-tag-slot other-pointer-lowtag)
     (storew lo dst simd-pack-lo-value-slot other-pointer-lowtag)
